Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.PullRequest) predicate.PullRequest
- func ClosedAt(v time.Time) predicate.PullRequest
- func ClosedAtEQ(v time.Time) predicate.PullRequest
- func ClosedAtGT(v time.Time) predicate.PullRequest
- func ClosedAtGTE(v time.Time) predicate.PullRequest
- func ClosedAtIn(vs ...time.Time) predicate.PullRequest
- func ClosedAtIsNil() predicate.PullRequest
- func ClosedAtLT(v time.Time) predicate.PullRequest
- func ClosedAtLTE(v time.Time) predicate.PullRequest
- func ClosedAtNEQ(v time.Time) predicate.PullRequest
- func ClosedAtNotIn(vs ...time.Time) predicate.PullRequest
- func ClosedAtNotNil() predicate.PullRequest
- func CreatedAt(v time.Time) predicate.PullRequest
- func CreatedAtEQ(v time.Time) predicate.PullRequest
- func CreatedAtGT(v time.Time) predicate.PullRequest
- func CreatedAtGTE(v time.Time) predicate.PullRequest
- func CreatedAtIn(vs ...time.Time) predicate.PullRequest
- func CreatedAtLT(v time.Time) predicate.PullRequest
- func CreatedAtLTE(v time.Time) predicate.PullRequest
- func CreatedAtNEQ(v time.Time) predicate.PullRequest
- func CreatedAtNotIn(vs ...time.Time) predicate.PullRequest
- func GetCommit(v bool) predicate.PullRequest
- func GetCommitEQ(v bool) predicate.PullRequest
- func GetCommitNEQ(v bool) predicate.PullRequest
- func GithubID(v string) predicate.PullRequest
- func GithubIDContains(v string) predicate.PullRequest
- func GithubIDContainsFold(v string) predicate.PullRequest
- func GithubIDEQ(v string) predicate.PullRequest
- func GithubIDEqualFold(v string) predicate.PullRequest
- func GithubIDGT(v string) predicate.PullRequest
- func GithubIDGTE(v string) predicate.PullRequest
- func GithubIDHasPrefix(v string) predicate.PullRequest
- func GithubIDHasSuffix(v string) predicate.PullRequest
- func GithubIDIn(vs ...string) predicate.PullRequest
- func GithubIDLT(v string) predicate.PullRequest
- func GithubIDLTE(v string) predicate.PullRequest
- func GithubIDNEQ(v string) predicate.PullRequest
- func GithubIDNotIn(vs ...string) predicate.PullRequest
- func HasCommits() predicate.PullRequest
- func HasCommitsWith(preds ...predicate.Commits) predicate.PullRequest
- func HasRepository() predicate.PullRequest
- func HasRepositoryWith(preds ...predicate.Repository) predicate.PullRequest
- func ID(id uuid.UUID) predicate.PullRequest
- func IDEQ(id uuid.UUID) predicate.PullRequest
- func IDGT(id uuid.UUID) predicate.PullRequest
- func IDGTE(id uuid.UUID) predicate.PullRequest
- func IDIn(ids ...uuid.UUID) predicate.PullRequest
- func IDLT(id uuid.UUID) predicate.PullRequest
- func IDLTE(id uuid.UUID) predicate.PullRequest
- func IDNEQ(id uuid.UUID) predicate.PullRequest
- func IDNotIn(ids ...uuid.UUID) predicate.PullRequest
- func MergedAt(v time.Time) predicate.PullRequest
- func MergedAtEQ(v time.Time) predicate.PullRequest
- func MergedAtGT(v time.Time) predicate.PullRequest
- func MergedAtGTE(v time.Time) predicate.PullRequest
- func MergedAtIn(vs ...time.Time) predicate.PullRequest
- func MergedAtIsNil() predicate.PullRequest
- func MergedAtLT(v time.Time) predicate.PullRequest
- func MergedAtLTE(v time.Time) predicate.PullRequest
- func MergedAtNEQ(v time.Time) predicate.PullRequest
- func MergedAtNotIn(vs ...time.Time) predicate.PullRequest
- func MergedAtNotNil() predicate.PullRequest
- func Not(p predicate.PullRequest) predicate.PullRequest
- func Or(predicates ...predicate.PullRequest) predicate.PullRequest
- func Title(v string) predicate.PullRequest
- func TitleContains(v string) predicate.PullRequest
- func TitleContainsFold(v string) predicate.PullRequest
- func TitleEQ(v string) predicate.PullRequest
- func TitleEqualFold(v string) predicate.PullRequest
- func TitleGT(v string) predicate.PullRequest
- func TitleGTE(v string) predicate.PullRequest
- func TitleHasPrefix(v string) predicate.PullRequest
- func TitleHasSuffix(v string) predicate.PullRequest
- func TitleIn(vs ...string) predicate.PullRequest
- func TitleLT(v string) predicate.PullRequest
- func TitleLTE(v string) predicate.PullRequest
- func TitleNEQ(v string) predicate.PullRequest
- func TitleNotIn(vs ...string) predicate.PullRequest
- func TotalCommits(v int64) predicate.PullRequest
- func TotalCommitsEQ(v int64) predicate.PullRequest
- func TotalCommitsGT(v int64) predicate.PullRequest
- func TotalCommitsGTE(v int64) predicate.PullRequest
- func TotalCommitsIn(vs ...int64) predicate.PullRequest
- func TotalCommitsLT(v int64) predicate.PullRequest
- func TotalCommitsLTE(v int64) predicate.PullRequest
- func TotalCommitsNEQ(v int64) predicate.PullRequest
- func TotalCommitsNotIn(vs ...int64) predicate.PullRequest
- func UpdatedAt(v time.Time) predicate.PullRequest
- func UpdatedAtEQ(v time.Time) predicate.PullRequest
- func UpdatedAtGT(v time.Time) predicate.PullRequest
- func UpdatedAtGTE(v time.Time) predicate.PullRequest
- func UpdatedAtIn(vs ...time.Time) predicate.PullRequest
- func UpdatedAtLT(v time.Time) predicate.PullRequest
- func UpdatedAtLTE(v time.Time) predicate.PullRequest
- func UpdatedAtNEQ(v time.Time) predicate.PullRequest
- func UpdatedAtNotIn(vs ...time.Time) predicate.PullRequest
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the pullrequest type in the database. Label = "pull_request" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldGithubID holds the string denoting the github_id field in the database. FieldGithubID = "github_id" // FieldTitle holds the string denoting the title field in the database. FieldTitle = "title" // FieldTotalCommits holds the string denoting the total_commits field in the database. FieldTotalCommits = "total_commits" // FieldGetCommit holds the string denoting the get_commit field in the database. FieldGetCommit = "get_commit" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldClosedAt holds the string denoting the closed_at field in the database. FieldClosedAt = "closed_at" // FieldMergedAt holds the string denoting the merged_at field in the database. FieldMergedAt = "merged_at" // EdgeCommits holds the string denoting the commits edge name in mutations. EdgeCommits = "commits" // EdgeRepository holds the string denoting the repository edge name in mutations. EdgeRepository = "repository" // Table holds the table name of the pullrequest in the database. Table = "pull_requests" // CommitsTable is the table that holds the commits relation/edge. CommitsTable = "commits" // CommitsInverseTable is the table name for the Commits entity. // It exists in this package in order to avoid circular dependency with the "commits" package. CommitsInverseTable = "commits" // CommitsColumn is the table column denoting the commits relation/edge. CommitsColumn = "pull_request_id" // RepositoryTable is the table that holds the repository relation/edge. RepositoryTable = "pull_requests" // RepositoryInverseTable is the table name for the Repository entity. // It exists in this package in order to avoid circular dependency with the "repository" package. RepositoryInverseTable = "repositories" // RepositoryColumn is the table column denoting the repository relation/edge. RepositoryColumn = "repository_id" )
Variables ¶
var ( // GithubIDValidator is a validator for the "github_id" field. It is called by the builders before save. GithubIDValidator func(string) error // TitleValidator is a validator for the "title" field. It is called by the builders before save. TitleValidator func(string) error // DefaultTotalCommits holds the default value on creation for the "total_commits" field. DefaultTotalCommits int64 // TotalCommitsValidator is a validator for the "total_commits" field. It is called by the builders before save. TotalCommitsValidator func(int64) error // DefaultGetCommit holds the default value on creation for the "get_commit" field. DefaultGetCommit bool // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // DefaultClosedAt holds the default value on creation for the "closed_at" field. DefaultClosedAt func() time.Time // DefaultMergedAt holds the default value on creation for the "merged_at" field. DefaultMergedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldGithubID, FieldTitle, FieldTotalCommits, FieldGetCommit, FieldCreatedAt, FieldUpdatedAt, FieldClosedAt, FieldMergedAt, }
Columns holds all SQL columns for pullrequest fields.
var ForeignKeys = []string{
"repository_id",
}
ForeignKeys holds the SQL foreign-keys that are owned by the "pull_requests" table and are not defined as standalone fields in the schema.
Functions ¶
func And ¶
func And(predicates ...predicate.PullRequest) predicate.PullRequest
And groups predicates with the AND operator between them.
func ClosedAt ¶
func ClosedAt(v time.Time) predicate.PullRequest
ClosedAt applies equality check predicate on the "closed_at" field. It's identical to ClosedAtEQ.
func ClosedAtEQ ¶
func ClosedAtEQ(v time.Time) predicate.PullRequest
ClosedAtEQ applies the EQ predicate on the "closed_at" field.
func ClosedAtGT ¶
func ClosedAtGT(v time.Time) predicate.PullRequest
ClosedAtGT applies the GT predicate on the "closed_at" field.
func ClosedAtGTE ¶
func ClosedAtGTE(v time.Time) predicate.PullRequest
ClosedAtGTE applies the GTE predicate on the "closed_at" field.
func ClosedAtIn ¶
func ClosedAtIn(vs ...time.Time) predicate.PullRequest
ClosedAtIn applies the In predicate on the "closed_at" field.
func ClosedAtIsNil ¶
func ClosedAtIsNil() predicate.PullRequest
ClosedAtIsNil applies the IsNil predicate on the "closed_at" field.
func ClosedAtLT ¶
func ClosedAtLT(v time.Time) predicate.PullRequest
ClosedAtLT applies the LT predicate on the "closed_at" field.
func ClosedAtLTE ¶
func ClosedAtLTE(v time.Time) predicate.PullRequest
ClosedAtLTE applies the LTE predicate on the "closed_at" field.
func ClosedAtNEQ ¶
func ClosedAtNEQ(v time.Time) predicate.PullRequest
ClosedAtNEQ applies the NEQ predicate on the "closed_at" field.
func ClosedAtNotIn ¶
func ClosedAtNotIn(vs ...time.Time) predicate.PullRequest
ClosedAtNotIn applies the NotIn predicate on the "closed_at" field.
func ClosedAtNotNil ¶
func ClosedAtNotNil() predicate.PullRequest
ClosedAtNotNil applies the NotNil predicate on the "closed_at" field.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.PullRequest
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.PullRequest
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.PullRequest
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.PullRequest
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.PullRequest
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.PullRequest
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.PullRequest
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.PullRequest
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.PullRequest
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func GetCommit ¶
func GetCommit(v bool) predicate.PullRequest
GetCommit applies equality check predicate on the "get_commit" field. It's identical to GetCommitEQ.
func GetCommitEQ ¶
func GetCommitEQ(v bool) predicate.PullRequest
GetCommitEQ applies the EQ predicate on the "get_commit" field.
func GetCommitNEQ ¶
func GetCommitNEQ(v bool) predicate.PullRequest
GetCommitNEQ applies the NEQ predicate on the "get_commit" field.
func GithubID ¶
func GithubID(v string) predicate.PullRequest
GithubID applies equality check predicate on the "github_id" field. It's identical to GithubIDEQ.
func GithubIDContains ¶
func GithubIDContains(v string) predicate.PullRequest
GithubIDContains applies the Contains predicate on the "github_id" field.
func GithubIDContainsFold ¶
func GithubIDContainsFold(v string) predicate.PullRequest
GithubIDContainsFold applies the ContainsFold predicate on the "github_id" field.
func GithubIDEQ ¶
func GithubIDEQ(v string) predicate.PullRequest
GithubIDEQ applies the EQ predicate on the "github_id" field.
func GithubIDEqualFold ¶
func GithubIDEqualFold(v string) predicate.PullRequest
GithubIDEqualFold applies the EqualFold predicate on the "github_id" field.
func GithubIDGT ¶
func GithubIDGT(v string) predicate.PullRequest
GithubIDGT applies the GT predicate on the "github_id" field.
func GithubIDGTE ¶
func GithubIDGTE(v string) predicate.PullRequest
GithubIDGTE applies the GTE predicate on the "github_id" field.
func GithubIDHasPrefix ¶
func GithubIDHasPrefix(v string) predicate.PullRequest
GithubIDHasPrefix applies the HasPrefix predicate on the "github_id" field.
func GithubIDHasSuffix ¶
func GithubIDHasSuffix(v string) predicate.PullRequest
GithubIDHasSuffix applies the HasSuffix predicate on the "github_id" field.
func GithubIDIn ¶
func GithubIDIn(vs ...string) predicate.PullRequest
GithubIDIn applies the In predicate on the "github_id" field.
func GithubIDLT ¶
func GithubIDLT(v string) predicate.PullRequest
GithubIDLT applies the LT predicate on the "github_id" field.
func GithubIDLTE ¶
func GithubIDLTE(v string) predicate.PullRequest
GithubIDLTE applies the LTE predicate on the "github_id" field.
func GithubIDNEQ ¶
func GithubIDNEQ(v string) predicate.PullRequest
GithubIDNEQ applies the NEQ predicate on the "github_id" field.
func GithubIDNotIn ¶
func GithubIDNotIn(vs ...string) predicate.PullRequest
GithubIDNotIn applies the NotIn predicate on the "github_id" field.
func HasCommits ¶
func HasCommits() predicate.PullRequest
HasCommits applies the HasEdge predicate on the "commits" edge.
func HasCommitsWith ¶
func HasCommitsWith(preds ...predicate.Commits) predicate.PullRequest
HasCommitsWith applies the HasEdge predicate on the "commits" edge with a given conditions (other predicates).
func HasRepository ¶
func HasRepository() predicate.PullRequest
HasRepository applies the HasEdge predicate on the "repository" edge.
func HasRepositoryWith ¶
func HasRepositoryWith(preds ...predicate.Repository) predicate.PullRequest
HasRepositoryWith applies the HasEdge predicate on the "repository" edge with a given conditions (other predicates).
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.PullRequest
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.PullRequest
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.PullRequest
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.PullRequest
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.PullRequest
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.PullRequest
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.PullRequest
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.PullRequest
IDNotIn applies the NotIn predicate on the ID field.
func MergedAt ¶
func MergedAt(v time.Time) predicate.PullRequest
MergedAt applies equality check predicate on the "merged_at" field. It's identical to MergedAtEQ.
func MergedAtEQ ¶
func MergedAtEQ(v time.Time) predicate.PullRequest
MergedAtEQ applies the EQ predicate on the "merged_at" field.
func MergedAtGT ¶
func MergedAtGT(v time.Time) predicate.PullRequest
MergedAtGT applies the GT predicate on the "merged_at" field.
func MergedAtGTE ¶
func MergedAtGTE(v time.Time) predicate.PullRequest
MergedAtGTE applies the GTE predicate on the "merged_at" field.
func MergedAtIn ¶
func MergedAtIn(vs ...time.Time) predicate.PullRequest
MergedAtIn applies the In predicate on the "merged_at" field.
func MergedAtIsNil ¶
func MergedAtIsNil() predicate.PullRequest
MergedAtIsNil applies the IsNil predicate on the "merged_at" field.
func MergedAtLT ¶
func MergedAtLT(v time.Time) predicate.PullRequest
MergedAtLT applies the LT predicate on the "merged_at" field.
func MergedAtLTE ¶
func MergedAtLTE(v time.Time) predicate.PullRequest
MergedAtLTE applies the LTE predicate on the "merged_at" field.
func MergedAtNEQ ¶
func MergedAtNEQ(v time.Time) predicate.PullRequest
MergedAtNEQ applies the NEQ predicate on the "merged_at" field.
func MergedAtNotIn ¶
func MergedAtNotIn(vs ...time.Time) predicate.PullRequest
MergedAtNotIn applies the NotIn predicate on the "merged_at" field.
func MergedAtNotNil ¶
func MergedAtNotNil() predicate.PullRequest
MergedAtNotNil applies the NotNil predicate on the "merged_at" field.
func Not ¶
func Not(p predicate.PullRequest) predicate.PullRequest
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.PullRequest) predicate.PullRequest
Or groups predicates with the OR operator between them.
func Title ¶
func Title(v string) predicate.PullRequest
Title applies equality check predicate on the "title" field. It's identical to TitleEQ.
func TitleContains ¶
func TitleContains(v string) predicate.PullRequest
TitleContains applies the Contains predicate on the "title" field.
func TitleContainsFold ¶
func TitleContainsFold(v string) predicate.PullRequest
TitleContainsFold applies the ContainsFold predicate on the "title" field.
func TitleEQ ¶
func TitleEQ(v string) predicate.PullRequest
TitleEQ applies the EQ predicate on the "title" field.
func TitleEqualFold ¶
func TitleEqualFold(v string) predicate.PullRequest
TitleEqualFold applies the EqualFold predicate on the "title" field.
func TitleGT ¶
func TitleGT(v string) predicate.PullRequest
TitleGT applies the GT predicate on the "title" field.
func TitleGTE ¶
func TitleGTE(v string) predicate.PullRequest
TitleGTE applies the GTE predicate on the "title" field.
func TitleHasPrefix ¶
func TitleHasPrefix(v string) predicate.PullRequest
TitleHasPrefix applies the HasPrefix predicate on the "title" field.
func TitleHasSuffix ¶
func TitleHasSuffix(v string) predicate.PullRequest
TitleHasSuffix applies the HasSuffix predicate on the "title" field.
func TitleIn ¶
func TitleIn(vs ...string) predicate.PullRequest
TitleIn applies the In predicate on the "title" field.
func TitleLT ¶
func TitleLT(v string) predicate.PullRequest
TitleLT applies the LT predicate on the "title" field.
func TitleLTE ¶
func TitleLTE(v string) predicate.PullRequest
TitleLTE applies the LTE predicate on the "title" field.
func TitleNEQ ¶
func TitleNEQ(v string) predicate.PullRequest
TitleNEQ applies the NEQ predicate on the "title" field.
func TitleNotIn ¶
func TitleNotIn(vs ...string) predicate.PullRequest
TitleNotIn applies the NotIn predicate on the "title" field.
func TotalCommits ¶
func TotalCommits(v int64) predicate.PullRequest
TotalCommits applies equality check predicate on the "total_commits" field. It's identical to TotalCommitsEQ.
func TotalCommitsEQ ¶
func TotalCommitsEQ(v int64) predicate.PullRequest
TotalCommitsEQ applies the EQ predicate on the "total_commits" field.
func TotalCommitsGT ¶
func TotalCommitsGT(v int64) predicate.PullRequest
TotalCommitsGT applies the GT predicate on the "total_commits" field.
func TotalCommitsGTE ¶
func TotalCommitsGTE(v int64) predicate.PullRequest
TotalCommitsGTE applies the GTE predicate on the "total_commits" field.
func TotalCommitsIn ¶
func TotalCommitsIn(vs ...int64) predicate.PullRequest
TotalCommitsIn applies the In predicate on the "total_commits" field.
func TotalCommitsLT ¶
func TotalCommitsLT(v int64) predicate.PullRequest
TotalCommitsLT applies the LT predicate on the "total_commits" field.
func TotalCommitsLTE ¶
func TotalCommitsLTE(v int64) predicate.PullRequest
TotalCommitsLTE applies the LTE predicate on the "total_commits" field.
func TotalCommitsNEQ ¶
func TotalCommitsNEQ(v int64) predicate.PullRequest
TotalCommitsNEQ applies the NEQ predicate on the "total_commits" field.
func TotalCommitsNotIn ¶
func TotalCommitsNotIn(vs ...int64) predicate.PullRequest
TotalCommitsNotIn applies the NotIn predicate on the "total_commits" field.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.PullRequest
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.PullRequest
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.PullRequest
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.PullRequest
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.PullRequest
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.PullRequest
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.PullRequest
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.PullRequest
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.PullRequest
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.